@@ -395,7 +395,7 @@ class Substitution(Defect):
         return sub_site.specie.oxi_state - orig_site.specie.oxi_state
 
     def __repr__(self) -> str:
-        """Representation of a vacancy defect."""
+        """Representation of a substitutional defect."""
         rm_species = get_element(self.defect_site.specie)
         sub_species = get_element(self.site.specie)
         return (
@@ -491,10 +491,10 @@ class Interstitial(Defect):
         return sub_site.specie.oxi_state
 
     def __repr__(self) -> str:
-        """Representation of a vacancy defect."""
+        """Representation of a interstitial defect."""
         sub_species = get_element(self.site.specie)
         fpos_str = ",".join(f"{x:.2f}" for x in self.site.frac_coords)
-        return f"{sub_species} intersitial site at " f"at site [{fpos_str}]"
+        return f"{sub_species} intersitial site at [{fpos_str}]"
 
 
 class DefectComplex(Defect):
@@ -522,7 +522,7 @@ class DefectComplex(Defect):
 
     def get_multiplicity(self) -> int:
         """Determine the multiplicity of the defect site within the structure."""
-        raise NotImplementedError("Complex defect multiplicity is not implemented.")
+        raise NotImplementedError("Not implemented for defect complexes")
 
     @property
     def element_changes(self) -> Dict[Element, int]:
@@ -595,11 +595,10 @@ class DefectComplex(Defect):
             update_structure(sc_structure, sc_site, defect_type=defect.defect_type)
         complex_pos /= len(self.defects)
         if dummy_species is not None:
-            sc_structure.insert(
-                0,
-                species=dummy_species,
-                coords=np.mod(complex_pos, 1),
-            )
+            for defect in self.defects:
+                dummy_pos = np.dot(defect.site.frac_coords, sc_mat_inv)
+                dummy_pos = np.mod(dummy_pos, 1)
+                sc_structure.insert(len(sc_structure), dummy_species, dummy_pos)
 
         return sc_structure
 
@@ -667,6 +666,12 @@ class Adsorbate(Interstitial):
         """Returns a name for this defect."""
         return f"{get_element(self.site.specie)}_{{ads}}"
 
+    def __repr__(self) -> str:
+        """Representation of a adsorbate defect."""
+        sub_species = get_element(self.site.specie)
+        fpos_str = ",".join(f"{x:.2f}" for x in self.site.frac_coords)
+        return f"{sub_species} adsorbate site at [{fpos_str}]"
+
 
 def get_element(sp_el: Species | Element) -> Element:
     """Get the element from a species or element."""
